@@ -3,7 +3,7 @@ use warnings;
 
 package HTTP::BrowserDetect;
 {
-  $HTTP::BrowserDetect::VERSION = '1.64';
+  $HTTP::BrowserDetect::VERSION = '1.66';
 }
 
 use vars qw(@ALL_TESTS);
@@ -90,6 +90,7 @@ our @IE_TESTS = qw(
     ie55up      ie6         ie7
     ie8         ie9         ie10
     ie11
+    ie_compat_mode
 );
 
 our @OPERA_TESTS = qw(
@@ -282,6 +283,10 @@ sub _test {
     # Trident Engine (detect early for sniffing out IE)
     $tests->{TRIDENT} = ( index( $ua, "trident/" ) != -1 );
 
+    if ( $tests->{TRIDENT} && $ua =~ /trident\/([\w\.\d]*)/ ) {
+        $self->{engine_version} = $1;
+    }
+
     # Browser version
     my ( $major, $minor, $beta ) = (
         $ua =~ m{
@@ -499,6 +504,11 @@ sub _test {
     $tests->{IE10} = ( $tests->{IE} && $major == 10 );
     $tests->{IE11} = ( $tests->{IE} && $major == 11 );
 
+    $tests->{IE_COMPAT_MODE}
+        = (    $tests->{IE7}
+            && $tests->{TRIDENT}
+            && $self->{engine_version} + 0 >= 4 );
+
     # Neoplanet browsers
 
     $tests->{NEOPLANET} = ( index( $ua, "neoplanet" ) != -1 );
@@ -674,17 +684,10 @@ sub _test {
     if ( $tests->{GECKO} ) {
         if ( $ua =~ /\([^)]*rv:([\w.\d]*)/ ) {
             $self->{gecko_version} = $1;
+            $self->{engine_version} = $1;
         }
     }
 
-    # Engines
-
-    $self->{engine_version} = $self->{gecko_version};
-
-    if ( $ua =~ /trident\/([\w\.\d]*)/ ) {
-        $self->{engine_version} = $1;
-    }
-
     # RealPlayer
     $tests->{REALPLAYER}
         = ( index( $ua, "(r1 " ) != -1 || index( $ua, "realplayer" ) != -1 );
@@ -1011,6 +1014,12 @@ sub os_version {
         return join '.', $1, $2, $3;
     }
 
+    # firefox in mac
+    # "Mozilla/5.0 (Macintosh; Intel Mac OS X 10.9; rv:25.0) Gecko/20100101 Firefox/25.0"
+    if ( $self->mac && $self->{user_agent} =~ m{ X \s (\d\d\.\d)}x ) {
+        return $1;
+    }
+
     if (   $self->winphone
        && $self->{user_agent} =~ m{Windows \s Phone \s \w{0,2} \s{0,1} (\d+\.\d+);}x )
     {
@@ -1474,13 +1483,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 HTTP::BrowserDetect - Determine Web browser, version, and platform from an HTTP user agent string
 
 =head1 VERSION
 
-version 1.64
+version 1.66
 
 =head1 SYNOPSIS
 
@@ -1746,6 +1757,13 @@ version separately.
 
 =head3 ie ie3 ie4 ie4up ie5 ie55 ie6 ie7 ie8 ie9 ie10 ie11
 
+=head3 ie_compat_mode
+
+The ie_compat_mode is used to determine if the IE user agent is for
+the compatibility mode view, in which case the real version of IE is
+higher than that detected. The true version of IE can be inferred from
+the version of Trident in the engine_version method.
+
 =head3 java
 
 =head3 konqueror
@@ -1984,6 +2002,8 @@ yeahoffline
 
 David Ihnen
 
+Hao Wu
+
 =head1 TO DO
 
 The C<_engine()> method currently only handles Gecko and Trident.  It needs to
